@@ -81,6 +81,7 @@ cb_mini_tweet_free (CbMiniTweet *t)
   guint i;
 
   g_free (t->text);
+  g_free (t->language);
 
   for (i = 0; i < t->n_medias; i ++)
     g_object_unref (t->medias[i]);
@@ -108,6 +109,8 @@ cb_mini_tweet_copy (const CbMiniTweet *t1, CbMiniTweet *t2)
   cb_user_identity_copy (&t1->author, &t2->author);
   g_free (t2->text);
   t2->text = g_strdup (t1->text);
+  g_free (t2->language);
+  t2->language = g_strdup (t1->language);
 
   t2->n_entities = t1->n_entities;
   t2->entities = g_new0 (CbTextEntity, t2->n_entities);
@@ -175,6 +178,13 @@ cb_mini_tweet_parse (CbMiniTweet *t,
       t->display_range_start= 0;
     }
 
+  if (json_object_has_member (extended_object, "lang")) {
+    t->language = g_strdup(json_object_get_string_member (extended_object, "lang"));
+  }
+  else {
+    t->language = g_strdup("und");
+  }
+
   t->created_at = g_date_time_to_unix (time);
   cb_user_identity_parse (&t->author, json_object_get_object_member (obj, "user"));
 
@@ -256,7 +266,7 @@ cb_mini_tweet_parse_entities (CbMiniTweet *t,
         {
           t->reply_users[0].id = reply_to_user_id;
           t->reply_users[0].screen_name = g_strdup (json_object_get_string_member (status, "in_reply_to_screen_name"));
-          t->reply_users[0].user_name = g_strdup ("");
+          t->reply_users[0].user_name = (reply_to_user_id == t->author.id) ? g_strdup(t->author.user_name) : g_strdup ("");
           reply_index = 1;
         }
 
@@ -269,7 +279,7 @@ cb_mini_tweet_parse_entities (CbMiniTweet *t,
           JsonObject *mention = json_node_get_object (json_array_get_element (user_mentions, i));
           t->reply_users[reply_index].id = json_object_get_int_member (mention, "id");
           t->reply_users[reply_index].screen_name = g_strdup (json_object_get_string_member (mention, "screen_name"));
-          t->reply_users[reply_index].user_name = g_strdup (json_object_get_string_member (mention, "name"));
+          t->reply_users[reply_index].user_name = cb_utils_escape_ampersands (json_object_get_string_member (mention, "name"));
           reply_index ++;
         }
     }
@@ -283,10 +293,6 @@ cb_mini_tweet_parse_entities (CbMiniTweet *t,
 
   t->medias   = g_new0 (CbMedia*, media_count);
   t->entities = g_new0 (CbTextEntity, max_entities);
-  /*
-   * TODO: display_text and tooltip_text are often the same here, can we just set them to the
-   *       same value and only free one?
-   */
 
   /* URLS */
   for (i  = 0, p = json_array_get_length (urls); i < p; i ++)
@@ -297,7 +303,7 @@ cb_mini_tweet_parse_entities (CbMiniTweet *t,
       indices = json_object_get_array_member (url, "indices");
       t->entities[url_index].from = json_array_get_int_element (indices, 0);
       t->entities[url_index].to   = json_array_get_int_element (indices, 1);
-      t->entities[url_index].original_text = g_strdup (json_object_get_string_member (url, "url"));
+      t->entities[url_index].original_text = cb_utils_escape_ampersands (json_object_get_string_member (url, "url"));
       t->entities[url_index].display_text = cb_utils_escape_ampersands (json_object_get_string_member (url, "display_url"));
       t->entities[url_index].tooltip_text = cb_utils_escape_ampersands (expanded_url);
       t->entities[url_index].target = cb_utils_escape_ampersands (expanded_url);
@@ -372,7 +378,7 @@ cb_mini_tweet_parse_entities (CbMiniTweet *t,
 
           t->entities[url_index].from = json_array_get_int_element (indices, 0);
           t->entities[url_index].to   = json_array_get_int_element (indices, 1);
-          t->entities[url_index].original_text = g_strdup (json_object_get_string_member (url, "url"));
+          t->entities[url_index].original_text = cb_utils_escape_ampersands (json_object_get_string_member (url, "url"));
           t->entities[url_index].display_text = cb_utils_escape_ampersands (json_object_get_string_member (url, "display_url"));
           t->entities[url_index].target = url_str;
 
@@ -403,9 +409,10 @@ cb_mini_tweet_parse_entities (CbMiniTweet *t,
                   t->medias[t->n_medias]->type = CB_MEDIA_TYPE_IMAGE;
                   t->medias[t->n_medias]->url = g_strdup_printf ("%s:large", url);
                   t->medias[t->n_medias]->target_url = g_strdup_printf ("%s:orig", url);
+
                   if (json_object_has_member (media_obj, "ext_alt_text")) {
                     // Only "extended media" has alt text
-                    t->medias[t->n_medias]->alt_text = g_strdup (json_object_get_string_member (media_obj, "ext_alt_text"));
+                    t->medias[t->n_medias]->alt_text = g_strdup(json_object_get_string_member (media_obj, "ext_alt_text"));
                   }
 
                   if (json_object_has_member (media_obj, "sizes"))
@@ -488,9 +495,9 @@ cb_mini_tweet_parse_entities (CbMiniTweet *t,
               if (variant != NULL)
                 {                  
                   t->medias[t->n_medias] = cb_media_new ();
-                  t->medias[t->n_medias]->url = g_strdup (json_object_get_string_member (variant, "url"));
+                  t->medias[t->n_medias]->url = g_strdup(json_object_get_string_member (variant, "url"));
                   t->medias[t->n_medias]->thumb_url = g_strdup (thumb_url);
-                  t->medias[t->n_medias]->target_url = target_url ? g_strdup(target_url) : NULL;
+                  t->medias[t->n_medias]->target_url = target_url ? g_strdup (target_url) : NULL;
                   t->medias[t->n_medias]->type   = CB_MEDIA_TYPE_TWITTER_VIDEO;
                   t->medias[t->n_medias]->width  = width;
                   t->medias[t->n_medias]->height = height;
@@ -499,7 +506,7 @@ cb_mini_tweet_parse_entities (CbMiniTweet *t,
 
                   if (json_object_has_member (media_obj, "ext_alt_text")) {
                     // Only "extended media" for GIFs has alt text. Videos never do.
-                    t->medias[t->n_medias]->alt_text = g_strdup (json_object_get_string_member (media_obj, "ext_alt_text"));
+                    t->medias[t->n_medias]->alt_text = g_strdup(json_object_get_string_member (media_obj, "ext_alt_text"));
                   }
                   
                   if (t->medias[t->n_medias]->alt_text == NULL && json_object_has_member (media_obj, "additional_media_info")) {
