@@ -165,60 +165,12 @@ cb_utils_linkify_user (const CbUserIdentity *user,
   g_string_append (str, "</a></span>");
 }
 
-void
-cb_utils_write_reply_text (const CbMiniTweet *t,
-                           GString           *str)
-{
-
-  g_return_if_fail (t->reply_id != 0);
-  g_return_if_fail (t->n_reply_users > 0);
-  CbUserIdentity firstUser, secondUser;
-  int reply_users = 0;
-
-  for (int i = 0; i < t->n_reply_users; i++) {
-    CbUserIdentity user = t->reply_users[i];
-    if (user.id == t->author.id) {
-      continue;
-    }
-    if (reply_users == 0) {
-      firstUser = user;
-    } else if (reply_users == 1) {
-      secondUser = user;
-    }
-    reply_users++;
-  }
-
-  if (reply_users <= 0)
-    return;
-
-  /* TRANSLATORS: This is the start of a "Replying to" line in a tweet */
-  g_string_append (str, _("Replying to"));
-  g_string_append_c (str, ' ');
-
-  cb_utils_linkify_user (&firstUser, str);
-
-  if (reply_users == 2)
-    {
-      g_string_append_c (str, ' ');
-      /* TRANSLATORS: This gets appended to the "replying to" line
-       * in a tweet. Example: "Replying to Foo and Bar" where
-       * "and Bar" comes from this string. */
-      g_string_append (str, _("and"));
-      g_string_append_c (str, ' ');
-      cb_utils_linkify_user (&secondUser, str);
-    }
-  else if (reply_users > 2)
-    {
-      g_string_append_c (str, ' ');
-      /* TRANSLATORS: This gets appended to the "replying to" line
-       * in a tweet */
-      g_string_append_printf (str, _("and %d others"), reply_users - 1);
-    }
-}
-
 char *
 cb_utils_escape_quotes (const char *in)
 {
+  if (in == NULL) {
+    return NULL;
+  }
   gsize bytes = strlen (in);
   gsize n_quotes = 0;
   const char *p = in;
@@ -276,6 +228,9 @@ cb_utils_escape_quotes (const char *in)
 char *
 cb_utils_escape_ampersands (const char *in)
 {
+  if (in == NULL) {
+    return NULL;
+  }
   gsize bytes = strlen (in);
   gsize n_ampersands = 0;
   const char *p = in;
@@ -410,8 +365,14 @@ cb_utils_parse_date (const char *_in)
         break;
     }
 
-
+#if GLIB_CHECK_VERSION(2, 68, 0)
+  time_zone = g_time_zone_new_identifier (in + 20);
+  if (!time_zone) {
+    time_zone = g_time_zone_new_utc ();
+  }
+#else
   time_zone = g_time_zone_new (in + 20);
+#endif
 
   result = g_date_time_new (time_zone,
                             year,
@@ -581,6 +542,8 @@ cb_utils_load_threaded_async  (RestProxyCall       *call,
     g_debug ("REST: %s", s);
     g_free (s);
   }
+#else
+  g_debug("REST: %s %s", rest_proxy_call_get_method(call), rest_proxy_call_get_function(call));
 #endif
 
   rest_proxy_call_invoke_async (call, cancellable, call_done_cb, task);
